
# Slot: is nearby variant of


holds between a sequence variant and a gene sequence that the variant is genomically close to.

URI: [biolink:is_nearby_variant_of](https://w3id.org/biolink/vocab/is_nearby_variant_of)


## Domain and Range

[SequenceVariant](SequenceVariant.md) &#8594;  <sub>0..\*</sub> [Gene](Gene.md)

## Parents

 *  is_a: [is sequence variant of](is_sequence_variant_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | GAMMA:0000102 |
| **Narrow Mappings:** | | SNPEFF:downstream_gene_variant |
|  | | SNPEFF:upstream_gene_variant |

